from typing import Optional

from clowmdb.models import User
from opentelemetry import trace
from sqlalchemy import select
from sqlalchemy.ext.asyncio import AsyncSession

tracer = trace.get_tracer_provider().get_tracer(__name__)


class CRUDUser:
    @staticmethod
    async def get(db: AsyncSession, uid: str) -> Optional[User]:
        """
        Get a user by its UID.

        Parameters
        ----------
        db : sqlalchemy.ext.asyncio.AsyncSession.
            Async database session to perform query on.
        uid : str
            UID of a user.

        Returns
        -------
        user : clowmdb.models.User | None
            The user for the given UID if he exists, None otherwise
        """
        with tracer.start_as_current_span("db_get_user") as span:
            stmt = select(User).where(User.uid == uid)
            span.set_attribute("sql_query", str(stmt))
            return await db.scalar(stmt)
